@@ -873,8 +873,9 @@ class Trait(str, Enum):
     gubijin = "gubijin"
     yuMeiren = "yuMeiren"
     milleniumCastle = "milleniumCastle"
-    protoMerlinDrainNP = "protoMerlinDrainNP"
+    protoMerlinNPChargeBlock = "protoMerlinNPChargeBlock"
     valkyrie = "valkyrie"
+    immuneToPigify = "immuneToPigify"
 
 
 TRAIT_NAME: dict[int, Trait] = {
@@ -1032,7 +1033,8 @@ TRAIT_NAME: dict[int, Trait] = {
     2828: Trait.exaltation,
     2829: Trait.milleniumCastle,
     2833: Trait.yuMeiren,
-    2836: Trait.protoMerlinDrainNP,
+    2835: Trait.immuneToPigify,
+    2836: Trait.protoMerlinNPChargeBlock,
     2837: Trait.valkyrie,
     # 2xxx: CQ or Story quests buff
     3000: Trait.attackPhysical,  # Normal attack, including NP
